21 Ocak 2018 Pazar

Acil Müdahele Windows (CMD) Komutları

wmic startup list full; Başlangıçta çalışan Programları Listeler.

ipconfig /displaydns; En son ziyaret ettiğiniz web adresleri dns belleğinde tutar bu belleğe cach denir, Cache geçici bir bellektir bunun bir yaşam süresi vardır . Bu komut ziyaret edilen siteleri yani cache bellekdeki hafızayı size liste halinde listeler.

ipconfig /flushdns; ipconfig /displaydns; komutu ile görüntülediğiniz cache belleği siler.

wmic process get description,processid,parentprocessid,commandline /format:csv; Mevcutta çalışan işlemlerin yazılan sütunlara uygun biçimde CSV (virgülle ayrılmış veri dosyası) olarak listeler.

wmic service list full | more; Windowsta çalışan tüm servisleri gösterir. | more paremetresi sayfalama içindir.

netstat -bona;Tüm açık socket bağlantılarını PID ve EXE bağlantılarıyla gösterir.
Parametreleri;
-a : Tüm TCP ve UDP bağlantıları ekrana basar.
-e : Gelen ve giden paket sayısının istatistiklerini görüntüler.
-n : Tüm bağlantıları rakamsal olarak görüntüler.
-o : Tüm bağlantıları PID numarası ve uygulama adına göre listeler.
-p : Bağlantıların kullandığı uygulama ve PID numaralarını ekrana basar.
-s : Kurallara göre istatistiksel verileri ekrana basar.
-r : IP yönlendirme tablosunun içeriğini görüntüler.

Bağlantı durumları;

ESTABLISHED : Soket bağlantı gerçekleşmiş durumdadır.
SYN_SENT : Soket bağlantı kurmaya çalışıyordur.
SYN_RECV : Ağdan bir bağlantı isteği gelmiştir. FIN_WAIT1 : Soket kapatılmış, bağlantı sonlandırılmak üzeredir.
FIN_WAIT2 : Bağlantı sonlandırılmıştır.Soket karşı ucun bağlantıyı sonlandırmasını beklemektedir.
TIME_WAIT : Soket kapandıktan sonra gelebilecek paketleri alabilmek için beklemektedir.
CLOSED : Soket kullanılmamaktadır.
CLOSE_WAIT : Karşı uç bağlantıyı kapatmıştır. Soketin kapanması beklenmektedir.
LAST_ACK : Karşı uç bağlantıyı sonlandırmış ve soketi kapatmıştır.Onay beklenmektedir.
LISTEN : Soket gelebilecek bağlantılar için dinleme konumundadır.
CLOSING : Yerel ve uzak soketler kapatılmış fakat tüm verilerini göndermemiş durumdadır.Tüm veriler gönderilmeden soketler kapanmaz.
netstat -nty; Tüm TCP ve UDP Bağlantıları Listeler.

Sistemde çalışmış exe geçmişinin kayıt dosyasından alma;
reg export "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Session Manager\AppCompatCache" Kayit_dosya_ismi.reg
oluşturulan reg dosyasını çözümlemek için;
https://github.com/mandiant/ShimCacheParser adresinden ShimCacheParser-master.zip dosyası inidir ve aç.
pcde python kurulu olmalı veya kali linux kullan. Kayit_dosya_ismi.reg dosyasını açılan klasörün içine at ve
python ShimCacheParser.py -o cikis_dosya_ismi.csv -r Kayit_dosya_ismi.reg

cikis_dosya_ismi.csv dosyayı excelde içe aktar veya istediğin gibi aç ve filtrele.

19 Ocak 2018 Cuma

12 Ocak 2018 Cuma

Wapiti 3.0.0 - Web-Uygulama Güvenlik Açığı Tarayıcısı

Wapiti, web sitelerinin veya web uygulamalarınızın güvenliğini denetlemenizi sağlar.

Wapiti aşağıdaki güvenlik açıklarını tespit edebilir:


Windows altında Kali Linux Çalıştırma


1. Windows 10 güncelleyin. Bir PowerShell penceresi açın ve Windows Alt Sistemini yükleyin. Bittiğinde yeniden başlatır.
Enable-WindowsOptionalFeature -Online -FeatureName Microsoft-Windows-Subsystem-Linux
2. Yeniden başlattıktan sonra, Bir PowerShell penceresi açın ve varsayılan Ubuntu ortamını yüklemek için aşağıdaki komutları çalıştırın. 
lxrun / install
3. WSL anhtarını kurun ve yükleyin, Kali tabanı indirin ve onu diske çıkarın:
git clone https://github.com/RoliSoft/WSL-Distribution-Switcher.git
cd WSL-Distribution-Switcher
python get-prebuilt.py kalilinux/kali-linux-docker
python install.py rootfs_kalilinux_kali-linux-docker_latest.tar.gz
lxrun /setdefaultuser root
4. Şimdi Kali, Windows 10 makinenizde kuruldu, "bash" komutunu çalıştırarak onunla etkileşimde bulunabilirsiniz:
bash
5. Bu noktada, Kali'nin içindesiniz ve normalde paketleri kurduğunuz gibi kullanabilirsiniz, araçları kullanın, vb. Önce bir güncelleme ve yükseltme yapmanızı şiddetle öneririz:
export LANG=C
apt-get update
apt-get dist-upgrade
Yukarıda açıklanan kurulumun video gösterimi:

https://www.kali.org/tutorials/kali-on-the-windows-subsystem-for-linux/



“unable to launch the application” hatası. Tübitak 4006 e-imza süreci onay sorunları.

2956a7a9-94e4-4610-85ba-ea312a34eb1dd.jpg
Şeklinde beklemeyin indirilenlere bakın orada "ejdq0c1bv9zfal063333nyyxp7smhj76djc4rxc95gjt.jnlp" diye bir dosya var onu çalıştırın.
2018-01-11_13-26-00.png
eğer üstteki hatayı verirse;
Bilgisayarınızdan Denetim Masasını, oradan da Java'yı açmanız gerekiyor. Java Control Panel içerisindeki ilk sekme olan General sekmesindeki Temporary Internet Files bölümün altındaki View butonuna tıklıyorsunuz. Başlat- çalıştır "java" yazın çıkar. Şekildeki seçimi yap.
2018-01-11_13-16-54.png
sonra;
2018-01-11_13-16-12.png
bekleyin biraz bu pencere açılır. Listedeki tübitak yazanı seçin ve yukarıda işaretli yerdeki play butonuna basın bu şekilde imzalama süreci tamamlanacaktır.

Java security ayarları resimlerle;
Bilgisayarınızdan Denetim Masasını, oradan da Java'yı açmanız gerekiyor. Java Control Panel içerisindeki ilk sekme olan General sekmesindeki Temporary Internet Files bölümün altındaki View butonuna tıklıyorsunuz. Başlat- çalıştır "java" yazın çıkar. Şekildeki seçimi yap.2018-01-11_13-16-54 (2) (2).png
2018-01-11_13-47-46.png2018-01-11_13-48-23.png

8 Ocak 2018 Pazartesi

Chrome İçin Site Isolation – Site İzolasyonu

Bir chrome penceresi açın ve bu "chrome://flags/#enable-site-per-process " adres çubuğuna yapıştırın.2018-01-06_12-52-17 (2)
(java kökenli web sitelerde bulunan bazı exploitlere karşı)
Bu özellik etkinleştirilirse, Chrome’un kullanıcı tarafından ziyaret edilen herhangi bir alan için yeni işlemler oluşturuyor.
Bu istikrar ve güvenliği daha da arttırır, ancak bellek kullanımını artırır. Tarayıcının nasıl kullanıldığına bağlı olarak, Chrome tarafından daha fazla işlem oluşturulacağı için Sıkı site izolasyonu etkinleştirildiğinde bellek kullanımı %20 veya daha fazla artabilir.
Chrome tarayıcısı zaten çok miktarda bellek kullanıyor, ancak bilgisayarınızda yeterli RAM varsa, istikrarı ve güvenliği sağlamak için bu özelliği etkinleştirmek isteyebilirsiniz. Bilgisayarınızın RAM’i yeterli değilse, bu deneysel özellikleri çalıştırmanızı tavsiye etmiyoruz.
https://www.evrensel.net/yazi/80621/bitmeyecek-kriz-meltdown-ve-spectre
meltdown
spectre
Meltdown_spectre.jpg